@@ -3,8 +3,9 @@ package HTTP::Headers;
 use strict;
 use warnings;
 
-our $VERSION = '6.43';
+our $VERSION = '6.45';
 
+use Clone qw(clone);
 use Carp ();
 
 # The $TRANSLATE_UNDERSCORE variable controls whether '_' can be used
@@ -298,19 +299,6 @@ sub _process_newline {
 }
 
 
-
-if (eval { require Clone; 1 }) {
-    *clone = \&Clone::clone;
-} else {
-    *clone = sub {
-	my $self = shift;
-	my $clone = HTTP::Headers->new;
-	$self->scan(sub { $clone->push_header(@_);} );
-	$clone;
-    };
-}
-
-
 sub _date_header
 {
     require HTTP::Date;
@@ -475,7 +463,7 @@ HTTP::Headers - Class encapsulating HTTP Message headers
 
 =head1 VERSION
 
-version 6.43
+version 6.45
 
 =head1 SYNOPSIS
 
